@@ -89,7 +89,7 @@ const char sa_id[] = "OSSP sa";
 #endif
 
 /* backward compatibility for ssize_t */
-#if defined(HAVE_CONFIG_H) && !defined(HAVE_SSIZE_T)
+#if !defined(HAVE_SSIZE_T)
 #define ssize_t long
 #endif
 
